==> dde-introduction_1.0.2.orig.tar.xz: dde-introduction-1.0.2/translations/dde-introduction_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>About</name>
    <message>
        <location filename="../src/modules/about.cpp" line="33"/>
        <source>About us</source>
        <translation>Apie mus</translation>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="34"/>
        <source>deepin is a Linux distribution committed to providing elegant, user-friendly, safe and stable experience for users all over the world. It not only integrates and configures the best open-source products, but also develops a series of applications for daily use, such as Deepin Store, Deepin Screenshot, Deepin Music, Deepin Movie and so on, among which Deepin Desktop Environment and Deepin Control Center are based on Qt technology. deepin focuses on user-friendly experience and beautiful design, so it’s easy to install and use for most users and can well replace Windows for work and entertainment.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="35"/>
        <source>Objective</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="36"/>
        <source>Customer First</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="37"/>
        <source>Deepin Technology takes user requirements as core, adheres to innovative idea, and bases on the market demand to feedback users with better products and services.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="38"/>
        <source>Open Source Idea</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="39"/>
        <source>The deepin project is a creative and energetic open source desktop operating system. It insists on the open source idea always, the development are under GPL License and all codes are open source, which has been uploaded to GitHub. Community members, open source fans and Deepin Technology will develop the deepin project together to make a due contribution to China open source.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="40"/>
        <source>Open and Free</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="41"/>
        <source>Only in a comfortable, pleasure and free working environment, one can get high work efficiency. In Deepin Technology, no long and boring meeting and workflow, no complicated class hierarchy, all are equal and cooperative. It provides regular professional training, prospective career development and mature promote channel for employees.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="42"/>
        <source>Open source project</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="43"/>
        <source>deepin is an open source desktop system developed for common users. You are free to download, distribute, modify and use it. Detailed address is GitHub: https://github.com/linuxdeepin</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BottomNavigation</name>
    <message>
        <location filename="../src/widgets/bottomnavigation.cpp" line="30"/>
        <source>Home Page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/bottomnavigation.cpp" line="33"/>
        <source>Community</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/bottomnavigation.cpp" line="36"/>
        <source>Feedback</source>
        <translation>Atsiliepimas</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottomnavigation.cpp" line="39"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottomnavigation.cpp" line="42"/>
        <source>Acknowledgements</source>
        <translation>Padėkos</translation>
    </message>
</context>
<context>
    <name>DesktopModeModule</name>
    <message>
        <location filename="../src/modules/desktopmodemodule.cpp" line="27"/>
        <source>Efficient Mode</source>
        <translation>Efektyvi veiksena</translation>
    </message>
    <message>
        <location filename="../src/modules/desktopmodemodule.cpp" line="28"/>
        <source>Fashion Mode</source>
        <translation>Madinga veiksena</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>Next</source>
        <translation>Kitas</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="120"/>
        <source>Done</source>
        <translation>Atlikta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="248"/>
        <source>Please select desktop mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="249"/>
        <source>You can switch it in Mode by right clicking on dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="260"/>
        <source>Please select to enable window effect or not</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="261"/>
        <source>You can enable or disable it in Control Center &gt; Personalization &gt; Enable window effect, or use shortcuts Shift+Super+Tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="272"/>
        <source>Please select icon theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="273"/>
        <source>You can change it in Control Center &gt; Personalization &gt; Theme &gt; Icon Theme</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NormalModule</name>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="117"/>
        <source>Introduction</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="124"/>
        <source>Desktop mode</source>
        <translation>Darbalaukio veiksena</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="131"/>
        <source>Icon theme</source>
        <translation>Piktogramų tema</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="140"/>
        <source>Window effect</source>
        <translation>Langų efektas</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="148"/>
        <location filename="../src/modules/normalmodule.cpp" line="149"/>
        <source>Support us</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="155"/>
        <location filename="../src/modules/normalmodule.cpp" line="156"/>
        <source>About us</source>
        <translation>Apie mus</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="118"/>
        <source>Welcome</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="125"/>
        <source>Please select desktop mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="132"/>
        <source>Please select icon theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="141"/>
        <source>Please select to enable window effect or not</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Support</name>
    <message>
        <location filename="../src/modules/support.cpp" line="40"/>
        <source>Internationalization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="41"/>
        <source>deepin was born in China and aimed to go global. So as to make it possible for more and more users from around the world to experience the Linux distribution from China, let the system widely spread all over the world and enlarge its global impact, we hope that more and more people from the Linux community can join to help the translation work to let our open source work benefit the world!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="42"/>
        <source>The i18n translation work is mainly about:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="43"/>
        <source>deepin: Joining the document writing and i18n work to let our open source work benefit the world!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="44"/>
        <source>Deepin community: Providing community news, download, mirrors, projects and a gathering place for developers!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="45"/>
        <source>Welcome to join i18n project.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="46"/>
        <source>Donations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="47"/>
        <source>The development of deepin can not move on without community support, for further improve the construction of the deepin community environment, Deepin Technology has made the decision to officially open channels of donation.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="48"/>
        <source>The donation upholds the principle of completely voluntary and no matter who you are, wherever you are, how much you contribute, are all making contributions to the development of Deepin community and we are very grateful for your donation.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="49"/>
        <source>The donation aims to make a survey and decide the orientation and priority of the projects, support the continuous further development, and support community activities and construction.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="51"/>
        <source>For quality assurance of the deepin project, we welcome more people to participate in the internal testing and feedback tracking. Become an Internal Testing Team member, you will</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="50"/>
        <source>Internal Testing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="52"/>
        <source>Get the latest achievements of deepin and software timely.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="53"/>
        <source>Obtain the latest development plans and progress of deepin project in advance.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="54"/>
        <source>Be on deepin contributors list.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="55"/>
        <source>Outstanding members will get a souvenir of deepin.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <location filename="../src/modules/wmmodemodule.cpp" line="27"/>
        <source>Disable window effect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/wmmodemodule.cpp" line="28"/>
        <source>Enable window effect</source>
        <translation>Įjungti langų efektus</translation>
    </message>
</context>
</TS>

==> dde-introduction_1.1.9.1.orig.tar.xz: dde-introduction-1.1.9.1/translations/dde-introduction_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>About</name>
    <message>
        <location filename="../src/modules/about.cpp" line="36"/>
        <source>About us</source>
        <translation>Apie mus</translation>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="37"/>
        <source>deepin is a Linux distribution committed to providing elegant, user-friendly, safe and stable experience for users all over the world. It not only integrates and configures the best open-source products, but also develops a series of applications for daily use, such as Deepin Store, Deepin Screenshot, Deepin Music, Deepin Movie and so on, among which Deepin Desktop Environment and Deepin Control Center are based on Qt technology. deepin focuses on user-friendly experience and beautiful design, so it’s easy to install and use for most users and can well replace Windows for work and entertainment.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="38"/>
        <source>Objective</source>
        <translation>Tikslas</translation>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="39"/>
        <source>Customer First</source>
        <translation>Pirmiausia, klientas</translation>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="40"/>
        <source>Deepin Technology takes user requirements as core, adheres to innovative idea, and bases on the market demand to feedback users with better products and services.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="41"/>
        <source>Open Source Idea</source>
        <translation>Atvirojo kodo idėja</translation>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="42"/>
        <source>The deepin project is a creative and energetic open source desktop operating system. It insists on the open source idea always, the development are under GPL License and all codes are open source, which has been uploaded to GitHub. Community members, open source fans and Deepin Technology will develop the deepin project together to make a due contribution to China open source.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="43"/>
        <source>Open and Free</source>
        <translation>Atvira ir laisva</translation>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="44"/>
        <source>Only in a comfortable, pleasure and free working environment, one can get high work efficiency. In Deepin Technology, no long and boring meeting and workflow, no complicated class hierarchy, all are equal and cooperative. It provides regular professional training, prospective career development and mature promote channel for employees.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="45"/>
        <source>Open source project</source>
        <translation>Atvirojo kodo projektas</translation>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="46"/>
        <source>deepin is an open source desktop system developed for common users. You are free to download, distribute, modify and use it. Detailed address is GitHub: https://github.com/linuxdeepin</source>
        <translation>deepin yra atvirojo kodo darbalaukio sistema, sukurta įprastiems naudotojams. Jūs galite ją laisvai atsisiųsti, platinti, modifikuoti ir naudoti. Išsamesnis adresas yra GitHub: https://github.com/linuxdeepin</translation>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="52"/>
        <source>deepin, bringing the world&apos;s leading technology and innovation into government information construction and enterprise information technology infrastructure, is one of the fastest growing operating systems in China today. Because of its ease of use and extendibility, many government and enterprise users choose deepin as their daily operating system, while the information departments and the maintenance departments are attracted by the stability, security and flexibility of deepin desktop environment. Deepin desktop, which can be installed on laptops and desktops, is stable and efficient as well as very easy to use, based on the wonderful product design and the advanced technology. Its simple user experience can help users reduce the browsing and searching time, and put more time into work.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="53"/>
        <source>The research and development team of deepin - Wuhan Deepin Technology Co., Ltd (Deepin Technology), established in 2011, taking operating system products as the core, focuses on the development of operating system software based on the Linux kernel, and provides users with solutions, management, maintenance, consultation, customization, development and other related services. As the core product of Deepin Technology, deepin software has obtained various outstanding achievements in domestic Linux operating system products and has been widely recognized in the world. </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/about.cpp" line="54"/>
        <source>Deepin Technology will continue to adhere to the open source and innovative spirit, take the opportunity of autonomous, controllable and replaceable operating system, build domestic operating system ecosystem and become a leading supplier of basic software products and solutions.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BottomNavigation</name>
    <message>
        <location filename="../src/widgets/bottomnavigation.cpp" line="30"/>
        <source>Home Page</source>
        <translation>Svetainė</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottomnavigation.cpp" line="33"/>
        <source>Community</source>
        <translation>Bendruomenė</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottomnavigation.cpp" line="36"/>
        <source>Feedback</source>
        <translation>Atsiliepimai</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottomnavigation.cpp" line="39"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottomnavigation.cpp" line="43"/>
        <source>Acknowledgements</source>
        <translation>Padėkos</translation>
    </message>
</context>
<context>
    <name>DesktopModeModule</name>
    <message>
        <location filename="../src/modules/desktopmodemodule.cpp" line="27"/>
        <source>Efficient Mode</source>
        <translation>Efektyvi veiksena</translation>
    </message>
    <message>
        <location filename="../src/modules/desktopmodemodule.cpp" line="28"/>
        <source>Fashion Mode</source>
        <translation>Madinga veiksena</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>Next</source>
        <translation>Kitas</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="120"/>
        <source>Done</source>
        <translation>Atlikta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="269"/>
        <source>Please select desktop mode</source>
        <translation>Pasirinkite darbalaukio veikseną</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="270"/>
        <source>You can switch it in Mode by right clicking on dock</source>
        <translation>Galėsite ją pakeisti, spustelėję dešiniu mygtuku ant doko ir pasirinkę Veiksena</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="281"/>
        <source>Please select to enable window effect or not</source>
        <translation>Pasirinkite ar įjungti langų efektus, ar ne</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="282"/>
        <source>You can enable or disable it in Control Center &gt; Personalization &gt; Enable window effect, or use shortcuts Shift+Super+Tab</source>
        <translation>Galite juos įjungti arba išjungti perėję į Valdymo centras &gt; Personalizacija &gt; Įjungti langų efektus, arba pasinaudoję sparčiuoju klavišu Lyg2+Super+Tab</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="293"/>
        <source>Please select icon theme</source>
        <translation>Pasirinkite piktogramų temą</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="294"/>
        <source>You can change it in Control Center &gt; Personalization &gt; Theme &gt; Icon Theme</source>
        <translation>Galite ją keisti, perėję į Valdymo centras &gt; Personalizacija &gt; Tema &gt; Piktogramų tema</translation>
    </message>
</context>
<context>
    <name>NormalModule</name>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="114"/>
        <source>Introduction</source>
        <translation>Įžanga</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="125"/>
        <source>Desktop mode</source>
        <translation>Darbalaukio veiksena</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="135"/>
        <source>Icon theme</source>
        <translation>Piktogramų tema</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="147"/>
        <source>Window effect</source>
        <translation>Langų efektai</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="159"/>
        <location filename="../src/modules/normalmodule.cpp" line="160"/>
        <source>Support us</source>
        <translation>Palaikykite mus</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="170"/>
        <location filename="../src/modules/normalmodule.cpp" line="171"/>
        <source>About us</source>
        <translation>Apie mus</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="115"/>
        <source>Welcome</source>
        <translation>Sveiki</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="126"/>
        <source>Please select desktop mode</source>
        <translation>Pasirinkite darbalaukio veikseną</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="136"/>
        <source>Please select icon theme</source>
        <translation>Pasirinkite piktogramų temą</translation>
    </message>
    <message>
        <location filename="../src/modules/normalmodule.cpp" line="148"/>
        <source>Please select to enable window effect or not</source>
        <translation>Pasirinkite ar įjungti langų efektus, ar ne</translation>
    </message>
</context>
<context>
    <name>Support</name>
    <message>
        <location filename="../src/modules/support.cpp" line="40"/>
        <source>Internationalization</source>
        <translation>Internacionalizacija</translation>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="41"/>
        <source>deepin was born in China and aimed to go global. So as to make it possible for more and more users from around the world to experience the Linux distribution from China, let the system widely spread all over the world and enlarge its global impact, we hope that more and more people from the Linux community can join to help the translation work to let our open source work benefit the world!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="42"/>
        <source>The i18n translation work is mainly about:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="43"/>
        <source>deepin: Joining the document writing and i18n work to let our open source work benefit the world!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="44"/>
        <source>Deepin community: Providing community news, download, mirrors, projects and a gathering place for developers!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="45"/>
        <source>Welcome to join i18n project.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="46"/>
        <source>Donations</source>
        <translation>Paaukojimai</translation>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="47"/>
        <source>The development of deepin can not move on without community support, for further improve the construction of the deepin community environment, Deepin Technology has made the decision to officially open channels of donation.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="48"/>
        <source>The donation upholds the principle of completely voluntary and no matter who you are, wherever you are, how much you contribute, are all making contributions to the development of Deepin community and we are very grateful for your donation.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="49"/>
        <source>The donation aims to make a survey and decide the orientation and priority of the projects, support the continuous further development, and support community activities and construction.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="51"/>
        <source>For quality assurance of the deepin project, we welcome more people to participate in the internal testing and feedback tracking. Become an Internal Testing Team member, you will</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="50"/>
        <source>Internal Testing</source>
        <translation>Vidinis testavimas</translation>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="52"/>
        <source>Get the latest achievements of deepin and software timely.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="53"/>
        <source>Obtain the latest development plans and progress of deepin project in advance.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="54"/>
        <source>Be on deepin contributors list.</source>
        <translation>Būsite deepin talkininkų sąraše.</translation>
    </message>
    <message>
        <location filename="../src/modules/support.cpp" line="55"/>
        <source>Outstanding members will get a souvenir of deepin.</source>
        <translation>Išskirtiniai nariai gaus deepin suvenyrą.</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <location filename="../src/modules/wmmodemodule.cpp" line="27"/>
        <source>Disable window effect</source>
        <translation>Išjungti langų efektus</translation>
    </message>
    <message>
        <location filename="../src/modules/wmmodemodule.cpp" line="28"/>
        <source>Enable window effect</source>
        <translation>Įjungti langų efektus</translation>
    </message>
</context>
</TS>
